@@ -30,6 +30,16 @@ def check_ext(fname, ext='.nii.gz'):
     return f'{fname}{ext}'
 
 
+def check_img_equal(img1, img2):
+    """
+    Check that two images are the same
+    """
+    try:
+        np.all(img1.header['dim'] == img2.header['dim'])
+    except:
+        raise Exception('Images needs to have the same dimensions!')
+
+
 def load_nifti_get_mask(fname, dim=4):
     """
     Load a nifti file and returns its data, its image, and a 3d mask.
@@ -359,9 +369,26 @@ def compute_metric(data, atlas, mask, metric='avg', invert=False):
 
 def compute_som(fname, n_comp, outname='', max_iter=1000, tolerance=-1, init_mode='pca'):
     """
+    Workflow to compute temporal SOM on a (series of) nifti files.
+    
+    fname: str, path, or list
+        If list, concatenate inputs in time.
+
     init_mode: pca, rand
     """
-    data, mask, img = load_nifti_get_mask(check_ext(fname))
+    if type(fname) is str:
+        fname = [fname]
+
+    img = dict.fromkeys(fname)
+    data, mask, img = load_nifti_get_mask(check_ext(fname[0]))
+
+    for f in fname[1:]:
+        d, m, i = load_nifti_get_mask(check_ext(f))
+        check_img_equal(img, i)
+        data = np.concatenate((data, d), axis=-1)
+        mask = np.concatenate((mask, m), axis=-1)
+
+    mask = np.any(mask, axis=-1)
     data_mkd = apply_mask(data, mask)
 
     clus = som(data_mkd, n_comp, max_iter, tolerance, init_mode)
@@ -370,4 +397,5 @@ def compute_som(fname, n_comp, outname='', max_iter=1000, tolerance=-1, init_mod
 
     if outname == '':
         outname = f'som_{init_mode}_{n_comp}'
+
     export_nifti(clus_vol, img, outname)
